@@ -4,7 +4,7 @@
 modname = "inlinedit"
 distname = "cubicweb-inlinedit"
 
-numversion = (1, 5, 0)
+numversion = (1, 7, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -13,7 +13,8 @@ author_email = "contact@logilab.fr"
 description = "Extension of the `reledit` builtin feature"
 web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname
 
-__depends__ = {"cubicweb": ">= 3.30.0, <3.31", "cwtags": "<1.2.3"}
+__depends__ = {"cubicweb": ">= 3.32.0, < 3.33.0", "cwtags": ">=1.2.3"}
+
 __recommends__ = {}
 
 classifiers = [
